aboutsummaryrefslogtreecommitdiffstats
path: root/models/src/main
diff options
context:
space:
mode:
Diffstat (limited to 'models/src/main')
-rw-r--r--models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantMessageType.java6
-rw-r--r--models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantPrime.java (renamed from models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantUpdate.java)14
-rw-r--r--models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantPrimeAck.java (renamed from models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantUpdateAck.java)14
3 files changed, 17 insertions, 17 deletions
diff --git a/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantMessageType.java b/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantMessageType.java
index 502896188..474bcd36f 100644
--- a/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantMessageType.java
+++ b/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantMessageType.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * Copyright (C) 2021 Nordix Foundation.
+ * Copyright (C) 2021-2023 Nordix Foundation.
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -77,13 +77,13 @@ public enum ParticipantMessageType {
/**
* Used by automation composition runtime to send ToscaServiceTemplate to participant.
*/
- PARTICIPANT_UPDATE,
+ PARTICIPANT_PRIME,
/**
* Used by participant to acknowledge the receipt of PARTICIPANT_UPDATE message
* from automation composition runtime.
*/
- PARTICIPANT_UPDATE_ACK,
+ PARTICIPANT_PRIME_ACK,
/**
* Used by participant to acknowledge the receipt of AUTOMATION_COMPOSITION_DEPLOY message
diff --git a/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantUpdate.java b/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantPrime.java
index 36842a8cf..b9d82a5c8 100644
--- a/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantUpdate.java
+++ b/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantPrime.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * Copyright (C) 2021 Nordix Foundation.
+ * Copyright (C) 2021-2023 Nordix Foundation.
* Modifications Copyright (C) 2021 AT&T Intellectual Property. All rights reserved.
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
@@ -30,23 +30,23 @@ import org.onap.policy.clamp.models.acm.concepts.ParticipantDefinition;
import org.onap.policy.models.base.PfUtils;
/**
* Class to represent the PARTICIPANT_UPDATE message that the ACM runtime sends to a participant.
* the ACM Runtime sends automation composition element Definitions and Common Parameter Values to Participants.
*/
@Getter
@Setter
@ToString(callSuper = true)
-public class ParticipantUpdate extends ParticipantMessage {
+public class ParticipantPrime extends ParticipantMessage {
// A list of updates to ParticipantDefinitions
private List<ParticipantDefinition> participantDefinitionUpdates = new ArrayList<>();
/**
* Constructor for instantiating ParticipantUpdate class with message name.
*
*/
- public ParticipantUpdate() {
- super(ParticipantMessageType.PARTICIPANT_UPDATE);
+ public ParticipantPrime() {
+ super(ParticipantMessageType.PARTICIPANT_PRIME);
}
/**
@@ -54,7 +54,7 @@ public class ParticipantUpdate extends ParticipantMessage {
*
* @param source source from which to copy
*/
- public ParticipantUpdate(ParticipantUpdate source) {
+ public ParticipantPrime(ParticipantPrime source) {
super(source);
this.participantDefinitionUpdates = PfUtils.mapList(source.participantDefinitionUpdates,
@@ -30,23 +30,23 @@ import org.onap.policy.clamp.models.acm.concepts.ParticipantDefinition;
import org.onap.policy.models.base.PfUtils;
/**
- * Class to represent the PARTICIPANT_UPDATE message that the ACM runtime sends to a participant.
+ * Class to represent the PARTICIPANT_PRIME message that the ACM runtime sends to a participant.
* the ACM Runtime sends automation composition element Definitions and Common Parameter Values to Participants.
*/
@@ -30,23 +30,23 @@ import org.onap.policy.clamp.models.acm.concepts.ParticipantDefinition;
private List<ParticipantDefinition> participantDefinitionUpdates = new ArrayList<>();
/**
- * Constructor for instantiating ParticipantUpdate class with message name.
+ * Constructor for instantiating ParticipantPrime class with message name.
*
*/
diff --git a/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantUpdateAck.java b/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantPrimeAck.java
index 2c3a68e22..156fe919c 100644
--- a/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantUpdateAck.java
+++ b/models/src/main/java/org/onap/policy/clamp/models/acm/messages/dmaap/participant/ParticipantPrimeAck.java
@@ -1,6 +1,6 @@
/*-
* ============LICENSE_START=======================================================
- * Copyright (C) 2021 Nordix Foundation.
+ * Copyright (C) 2021-2023 Nordix Foundation.
* ================================================================================
* Modifications Copyright (C) 2021 AT&T Intellectual Property. All rights reserved.
* ================================================================================
@@ -27,19 +27,19 @@ import lombok.Setter;
import lombok.ToString;
/**
* Class to represent the PARTICIPANT_UPDATE_ACK message that registered participant sends to the ACM runtime.
*/
@Getter
@Setter
@ToString(callSuper = true)
-public class ParticipantUpdateAck extends ParticipantAckMessage {
+public class ParticipantPrimeAck extends ParticipantAckMessage {
/**
* Constructor for instantiating ParticipantUpdateAck class with message name.
*
*/
- public ParticipantUpdateAck() {
- super(ParticipantMessageType.PARTICIPANT_UPDATE_ACK);
+ public ParticipantPrimeAck() {
+ super(ParticipantMessageType.PARTICIPANT_PRIME_ACK);
}
/**
@@ -47,7 +47,7 @@ public class ParticipantUpdateAck extends ParticipantAckMessage {
*
* @param source source from which to copy
*/
- public ParticipantUpdateAck(final ParticipantUpdateAck source) {
+ public ParticipantPrimeAck(final ParticipantPrimeAck source) {
super(source);
}
}
@@ -27,19 +27,19 @@ import lombok.Setter;
import lombok.ToString;
/**
- * Class to represent the PARTICIPANT_UPDATE_ACK message that registered participant sends to the ACM runtime.
+ * Class to represent the PARTICIPANT_PRIME_ACK message that registered participant sends to the ACM runtime.
*/
@@ -27,19 +27,19 @@ import lombok.Setter;
/**
- * Constructor for instantiating ParticipantUpdateAck class with message name.
+ * Constructor for instantiating ParticipantPrimeAck class with message name.
*
*/